@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcebuffer.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 1999-2002 - Mikael Hermansson <tyan@linux.se>,
@@ -44,8 +44,7 @@
 #include "gtksourcemarkssequence.h"
 #include "gtksourcesearchcontext.h"
 #include "gtksourcetag.h"
-#include "gtksourceview-i18n.h"
-#include "gtksourceview-enumtypes.h"
+#include "gtksource-enumtypes.h"
 
 /**
  * SECTION:buffer
@@ -2052,6 +2051,12 @@ gtk_source_buffer_create_source_mark (GtkSourceBuffer   *buffer,
 				  GTK_TEXT_MARK (mark),
 				  where);
 
+	/* We want to return a borrowed reference and the mark is already
+	 * owned by @buffer due to gtk_text_buffer_add_mark(). Therefore
+	 * it is safe to unref immediately.
+	 */
+	g_object_unref (mark);
+
 	return mark;
 }
 
