@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcestylescheme.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2003 - Paolo Maggi <paolo.maggi@polito.it>
@@ -23,14 +23,14 @@
 #endif
 
 #include "gtksourcestylescheme.h"
+#include <libxml/parser.h>
+#include <string.h>
+#include <glib/gi18n-lib.h>
 #include "gtksourcestyleschememanager.h"
 #include "gtksourcestyle.h"
 #include "gtksourcestyle-private.h"
 #include "gtksourceview.h"
 #include "gtksourcelanguage-private.h"
-#include "gtksourceview-i18n.h"
-#include <libxml/parser.h>
-#include <string.h>
 
 /**
  * SECTION:stylescheme
@@ -134,7 +134,6 @@ gtk_source_style_scheme_finalize (GObject *object)
 
 	if (scheme->priv->authors != NULL)
 	{
-		g_ptr_array_foreach (scheme->priv->authors, (GFunc)g_free, NULL);
 		g_ptr_array_free (scheme->priv->authors, TRUE);
 	}
 
@@ -1234,7 +1233,7 @@ parse_style_scheme_child (GtkSourceStyleScheme *scheme,
 	{
 		xmlChar *tmp = xmlNodeGetContent (node);
 		if (scheme->priv->authors == NULL)
-			scheme->priv->authors = g_ptr_array_new ();
+			scheme->priv->authors = g_ptr_array_new_with_free_func (g_free);
 
 		g_ptr_array_add (scheme->priv->authors, g_strdup ((char*) tmp));
 
@@ -1441,6 +1440,11 @@ _gtk_source_style_scheme_set_parent (GtkSourceStyleScheme *scheme,
 	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme));
 	g_return_if_fail (parent_scheme == NULL || GTK_SOURCE_IS_STYLE_SCHEME (parent_scheme));
 
+	if (scheme->priv->parent == parent_scheme)
+	{
+		return;
+	}
+
 	g_clear_object (&scheme->priv->parent);
 
 	if (parent_scheme != NULL)
@@ -1449,6 +1453,10 @@ _gtk_source_style_scheme_set_parent (GtkSourceStyleScheme *scheme,
 	}
 
 	scheme->priv->parent = parent_scheme;
+
+	/* Update CSS based on parent styles */
+	g_hash_table_remove_all (scheme->priv->style_cache);
+	generate_css_style (scheme);
 }
 
 /**
